-- -----------------------------------------------------
-- Table IDN_CONFIG_TYPE
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS IDN_CONFIG_TYPE (
  ID          VARCHAR(255)  NOT NULL,
  NAME        VARCHAR(255)  NOT NULL,
  DESCRIPTION VARCHAR(1023) NULL,
  PRIMARY KEY (ID),
  CONSTRAINT TYPE_NAME_CONSTRAINT UNIQUE (NAME)
);

INSERT INTO IDN_CONFIG_TYPE (ID, NAME, DESCRIPTION) VALUES
('up2hxlkj-654n-1ujd-5wnf-uvhs3ppwf9j8', 'CORS', 'A resource type to keep the tenant CORS Origins');

-- -----------------------------------------------------
-- Table IDN_CONFIG_RESOURCE
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS IDN_CONFIG_RESOURCE (
  ID            VARCHAR(255) NOT NULL,
  TENANT_ID     INT          NOT NULL,
  NAME          VARCHAR(255) NOT NULL,
  CREATED_TIME  TIMESTAMP    NOT NULL,
  LAST_MODIFIED TIMESTAMP    NOT NULL,
  HAS_FILE      BOOLEAN(1)   NOT NULL,
  HAS_ATTRIBUTE BOOLEAN(1)   NOT NULL,
  TYPE_ID       VARCHAR(255) NOT NULL,
  UNIQUE (NAME, TENANT_ID, TYPE_ID),
  PRIMARY KEY (ID)
);

ALTER TABLE IDN_CONFIG_RESOURCE
  ADD CONSTRAINT TYPE_ID_FOREIGN_CONSTRAINT FOREIGN KEY (TYPE_ID) REFERENCES IDN_CONFIG_TYPE (ID) ON DELETE CASCADE ON UPDATE CASCADE;

-- -----------------------------------------------------
-- Table IDN_CONFIG_ATTRIBUTE
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS IDN_CONFIG_ATTRIBUTE (
  ID         VARCHAR(255)  NOT NULL,
  RESOURCE_ID  VARCHAR(255)  NOT NULL,
  ATTR_KEY   VARCHAR(1023) NOT NULL,
  ATTR_VALUE VARCHAR(1023) NULL,
  PRIMARY KEY (ID),
  UNIQUE (RESOURCE_ID, ATTR_KEY, ATTR_VALUE)
);
ALTER TABLE IDN_CONFIG_ATTRIBUTE
  ADD CONSTRAINT RESOURCE_ID_ATTRIBUTE_FOREIGN_CONSTRAINT FOREIGN KEY (RESOURCE_ID) REFERENCES IDN_CONFIG_RESOURCE (ID) ON DELETE CASCADE ON UPDATE CASCADE;

-- -----------------------------------------------------
-- Table IDN_CONFIG_FILE
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS IDN_CONFIG_FILE (
  ID        VARCHAR(255) NOT NULL,
  VALUE     BLOB         NULL,
  NAME        VARCHAR (255) NULL,
  RESOURCE_ID VARCHAR(255) NOT NULL,
  PRIMARY KEY (ID)
);
ALTER TABLE IDN_CONFIG_FILE
  ADD CONSTRAINT RESOURCE_ID_FILE_FOREIGN_CONSTRAINT FOREIGN KEY (RESOURCE_ID) REFERENCES IDN_CONFIG_RESOURCE (ID) ON DELETE CASCADE ON UPDATE CASCADE;
